import { Status } from './pb/index.js';
import { PeerMap } from '@libp2p/peer-collections';
import { DEFAULT_DATA_LIMIT, DEFAULT_DURATION_LIMIT } from './constants.js';
export class ReservationStore {
    constructor(options) {
        this.reservations = new PeerMap();
        this._started = false;
        this.init = {
            maxReservations: options?.maxReservations ?? 15,
            reservationClearInterval: options?.reservationClearInterval ?? 300 * 1000,
            applyDefaultLimit: options?.applyDefaultLimit !== false,
            reservationTtl: options?.reservationTtl ?? 2 * 60 * 60 * 1000,
            defaultDurationLimit: options?.defaultDurationLimit ?? DEFAULT_DURATION_LIMIT,
            defaultDataLimit: options?.defaultDataLimit ?? DEFAULT_DATA_LIMIT
        };
    }
    isStarted() {
        return this._started;
    }
    start() {
        if (this._started) {
            return;
        }
        this._started = true;
        this.interval = setInterval(() => {
            const now = (new Date()).getTime();
            this.reservations.forEach((r, k) => {
                if (r.expire.getTime() < now) {
                    this.reservations.delete(k);
                }
            });
        }, this.init.reservationClearInterval);
    }
    stop() {
        clearInterval(this.interval);
    }
    reserve(peer, addr, limit) {
        if (this.reservations.size >= this.init.maxReservations && !this.reservations.has(peer)) {
            return { status: Status.RESERVATION_REFUSED };
        }
        const expire = new Date(Date.now() + this.init.reservationTtl);
        let checkedLimit;
        if (this.init.applyDefaultLimit) {
            checkedLimit = limit ?? { data: this.init.defaultDataLimit, duration: this.init.defaultDurationLimit };
        }
        this.reservations.set(peer, { addr, expire, limit: checkedLimit });
        return { status: Status.OK, expire: expire.getTime() };
    }
    removeReservation(peer) {
        this.reservations.delete(peer);
    }
    hasReservation(dst) {
        return this.reservations.has(dst);
    }
    get(peer) {
        return this.reservations.get(peer);
    }
}
//# sourceMappingURL=reservation-store.js.map