import { symbol, TransportManager, Upgrader } from '@libp2p/interface-transport';
import type { AbortOptions } from '@libp2p/interfaces';
import type { IncomingStreamData, Registrar } from '@libp2p/interface-registrar';
import type { Listener, Transport, CreateListenerOptions } from '@libp2p/interface-transport';
import type { Connection, Stream } from '@libp2p/interface-connection';
import type { RelayConfig } from './index.js';
import type { PeerId } from '@libp2p/interface-peer-id';
import type { Multiaddr } from '@multiformats/multiaddr';
import type { PeerStore } from '@libp2p/interface-peer-store';
import type { Startable } from '@libp2p/interfaces/dist/src/startable';
import type { ConnectionManager } from '@libp2p/interface-connection-manager';
import type { AddressManager } from '@libp2p/interface-address-manager';
export interface CircuitOptions {
    limit?: number;
}
export interface CircuitComponents {
    peerId: PeerId;
    peerStore: PeerStore;
    registrar: Registrar;
    connectionManager: ConnectionManager;
    upgrader: Upgrader;
    addressManager: AddressManager;
    transportManager: TransportManager;
}
interface ConnectOptions {
    stream: Stream;
    connection: Connection;
    destinationPeer: PeerId;
    destinationAddr: Multiaddr;
    relayAddr: Multiaddr;
    ma: Multiaddr;
    disconnectOnFailure: boolean;
}
export declare class Circuit implements Transport, Startable {
    private handler?;
    private readonly components;
    private readonly reservationStore;
    private readonly _init;
    private _started;
    constructor(components: CircuitComponents, options: RelayConfig);
    isStarted(): boolean;
    start(): Promise<void>;
    stop(): Promise<void>;
    get [symbol](): true;
    get [Symbol.toStringTag](): string;
    onHop({ connection, stream }: IncomingStreamData): Promise<void>;
    onStop({ connection, stream }: IncomingStreamData): Promise<void>;
    /**
     * Dial a peer over a relay
     */
    dial(ma: Multiaddr, options?: AbortOptions): Promise<Connection>;
    connectV2({ stream, connection, destinationPeer, destinationAddr, relayAddr, ma, disconnectOnFailure }: ConnectOptions): Promise<Connection>;
    /**
     * Create a listener
     */
    createListener(options: CreateListenerOptions): Listener;
    /**
     * Filter check for all Multiaddrs that this transport can dial on
     *
     * @param {Multiaddr[]} multiaddrs
     * @returns {Multiaddr[]}
     */
    filter(multiaddrs: Multiaddr[]): Multiaddr[];
}
export {};
//# sourceMappingURL=transport.d.ts.map